.. image:: https://travis-ci.org/mitre/thumbtack.svg?branch=master
    :target: https://travis-ci.org/mitre/thumbtack

thumbtack
=========

Thumbtack is a web front-end providing a REST-ful API to mount and unmount
forensic disk images, built on top of the |imagemounter|_ library.

Documentation is available in the ``docs/`` directory or online at
https://thumbtack.readthedocs.io/en/latest.

Quick Start
-----------

Find the quick start information in ``docs/quickstart.rst``.

LICENSE
-------

Thumbtack is licensed under the `Apache License, Version 2.0
<https://www.apache.org/licenses/LICENSE-2.0.html>`_. See the `LICENSE` file for
more information.

RELEASE STATEMENT
-----------------
Approved for Public Release; Distribution Unlimited. Public Release Case Number 19-0358.


.. |imagemounter| replace:: ``imagemounter``
.. _imagemounter: https://imagemounter.readthedocs.io/en/latest/
